.. currentmodule:: sardana.macroserver.macroserver

:mod:`~sardana.macroserver.macroserver`
=======================================

.. automodule:: sardana.macroserver.macroserver

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MacroServer`

MacroServer
------------

.. inheritance-diagram:: MacroServer
    :parts: 1
    
.. autoclass:: MacroServer
    :show-inheritance:
